<p align='center'>
    <img height=200 width=200 src='https://raw.githubusercontent.com/Zype-Z/ZypeC/main/assets/favicon.png'>
</p>

# ZypeC
[![Generic badge](https://img.shields.io/badge/PyPI-v1.0-GREEN.svg)](https://shields.io/)&nbsp;[![PyPI Release Create](https://github.com/Zype-Z/ZypeC/actions/workflows/Create-Release.yaml/badge.svg)](https://github.com/Zype-Z/ZypeC/actions/workflows/Create-Release.yaml)&nbsp;[![CodeQL](https://github.com/Zype-Z/ZypeC/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/Zype-Z/ZypeC/actions/workflows/codeql-analysis.yml)<br>

## Installation

```shell
pip install ZypeC
```
Other options are available at [ZypeC Documentation](https://zype.cf)

## Verify Installation
You should verify the installation by running:
```shell
zype --version
```

## Usage

Open a Terminal and type:

```sh
zype <Filename> <Content-Type> <To What>
```

**Note**: Replace &lt;Filename&gt; with the file's name, &lt;Content-Type&gt; with the File's Type (e.g. *md* for Markdown, *zype* for Zype) and &lt;To What&gt; with the final Type (e.g. *html* for MarkDown to HTML Compilation, *json* for Zype to JSON Compilation).